@@ -1,18 +1,18 @@
 context("Table name escaping")
 
 test_that("Basic table names are escaped", {
-  expect_equal(fqtn("tbl"), dplyr::sql('"tbl"'))
-  expect_equal(fqtn("foo", schema="bar"), dplyr::sql('"bar"."foo"'))
-  expect_equal(fqtn("foo", schema="bar", catalog="baz"), dplyr::sql('"baz"."bar"."foo"'))
+  expect_equal(fqtn("tbl"), dbplyr::sql('"tbl"'))
+  expect_equal(fqtn("foo", schema="bar"), dbplyr::sql('"bar"."foo"'))
+  expect_equal(fqtn("foo", schema="bar", catalog="baz"), dbplyr::sql('"baz"."bar"."foo"'))
 })
 
 test_that("More complicated names are escaped", {
-  expect_equal(fqtn("foo bar"), dplyr::sql('"foo bar"'))
-  expect_equal(fqtn("foo bar", schema="baz"), dplyr::sql('"baz"."foo bar"'))
+  expect_equal(fqtn("foo bar"), dbplyr::sql('"foo bar"'))
+  expect_equal(fqtn("foo bar", schema="baz"), dbplyr::sql('"baz"."foo bar"'))
   expect_equal(fqtn("foo bar", schema="baz", catalog="quux quux"),
-               dplyr::sql('"quux quux"."baz"."foo bar"'))
+               dbplyr::sql('"quux quux"."baz"."foo bar"'))
   expect_equal(fqtn("foo", schema="baz", catalog="quux quux"),
-               dplyr::sql('"quux quux"."baz"."foo"'))
+               dbplyr::sql('"quux quux"."baz"."foo"'))
 })
 
 test_that("Invalid calls throw errors", {
@@ -23,4 +23,3 @@ test_that("Invalid calls throw errors", {
   expect_error(fqtn("foo", catalog="bar")) #need schema
   expect_error(fqtn(schema="foo", catalog="bar")) #need table
 })
-
